diff target-utils/libtiffs/globals.c @ 60:87cb03b35f77

target-utils: long-overdue s/mpffs/tiffs/ and s/MPFFS/TIFFS/ rename
author Mychaela Falconia <falcon@freecalypso.org>
date Wed, 26 Oct 2016 15:52:14 +0000
parents e7502631a0f9
children
line wrap: on
line diff
--- a/target-utils/libtiffs/globals.c	Wed Oct 26 15:28:29 2016 +0000
+++ b/target-utils/libtiffs/globals.c	Wed Oct 26 15:52:14 2016 +0000
@@ -1,8 +1,8 @@
 /* global variables for the MPFFS reader code */
 
 #include "types.h"
 #include "struct.h"
 
-struct inode *mpffs_active_index;
-int mpffs_root_ino;
-int mpffs_init_done;
+struct inode *tiffs_active_index;
+int tiffs_root_ino;
+int tiffs_init_done;
@@ -1,8 +1,8 @@
-/* global variables for the MPFFS reader code */
+/* global variables for the TIFFS reader code */
 
 #include "types.h"